Class: Google::Cloud::BareMetalSolution::V2::VolumeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::BareMetalSolution::V2::VolumeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb
Overview
Configuration parameters for a new volume.
Defined Under Namespace
Modules: Protocol, Type Classes: LunRange, NfsExport
Instance Attribute Summary collapse
-
#gcp_service ⇒ ::String
The GCP service of the storage volume.
-
#id ⇒ ::String
A transient unique identifier to identify a volume within an ProvisioningConfig request.
-
#lun_ranges ⇒ ::Array<::Google::Cloud::BareMetalSolution::V2::VolumeConfig::LunRange>
LUN ranges to be configured.
-
#machine_ids ⇒ ::Array<::String>
Machine ids connected to this volume.
-
#name ⇒ ::String
readonly
Output only.
-
#nfs_exports ⇒ ::Array<::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport>
NFS exports.
-
#performance_tier ⇒ ::Google::Cloud::BareMetalSolution::V2::VolumePerformanceTier
Performance tier of the Volume.
-
#protocol ⇒ ::Google::Cloud::BareMetalSolution::V2::VolumeConfig::Protocol
Volume protocol.
-
#size_gb ⇒ ::Integer
The requested size of this volume, in GB.
-
#snapshots_enabled ⇒ ::Boolean
Whether snapshots should be enabled.
-
#type ⇒ ::Google::Cloud::BareMetalSolution::V2::VolumeConfig::Type
The type of this Volume.
-
#user_note ⇒ ::String
User note field, it can be used by customers to add additional information for the BMS Ops team .
Instance Attribute Details
#gcp_service ⇒ ::String
Returns The GCP service of the storage volume. Available gcp_service are in https://cloud.google.com/bare-metal/docs/bms-planning.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#id ⇒ ::String
Returns A transient unique identifier to identify a volume within an ProvisioningConfig request.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#lun_ranges ⇒ ::Array<::Google::Cloud::BareMetalSolution::V2::VolumeConfig::LunRange>
Returns LUN ranges to be configured. Set only when protocol is PROTOCOL_FC.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#machine_ids ⇒ ::Array<::String>
Returns Machine ids connected to this volume. Set only when protocol is PROTOCOL_FC.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#name ⇒ ::String (readonly)
Returns Output only. The name of the volume config.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#nfs_exports ⇒ ::Array<::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport>
Returns NFS exports. Set only when protocol is PROTOCOL_NFS.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#performance_tier ⇒ ::Google::Cloud::BareMetalSolution::V2::VolumePerformanceTier
Returns Performance tier of the Volume. Default is SHARED.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#protocol ⇒ ::Google::Cloud::BareMetalSolution::V2::VolumeConfig::Protocol
Returns Volume protocol.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#size_gb ⇒ ::Integer
Returns The requested size of this volume, in GB.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#snapshots_enabled ⇒ ::Boolean
Returns Whether snapshots should be enabled.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#type ⇒ ::Google::Cloud::BareMetalSolution::V2::VolumeConfig::Type
Returns The type of this Volume.
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |
#user_note ⇒ ::String
Returns User note field, it can be used by customers to add additional information for the BMS Ops team .
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 345 class VolumeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A LUN(Logical Unit Number) range. # @!attribute [rw] quantity # @return [::Integer] # Number of LUNs to create. # @!attribute [rw] size_gb # @return [::Integer] # The requested size of each LUN, in GB. class LunRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A NFS export entry. # @!attribute [rw] network_id # @return [::String] # Network to use to publish the export. # @!attribute [rw] machine_id # @return [::String] # Either a single machine, identified by an ID, or a comma-separated # list of machine IDs. # # Note: The following fields are mutually exclusive: `machine_id`, `cidr`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cidr # @return [::String] # A CIDR range. # # Note: The following fields are mutually exclusive: `cidr`, `machine_id`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] permissions # @return [::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions] # Export permissions. # @!attribute [rw] no_root_squash # @return [::Boolean] # Disable root squashing, which is a feature of NFS. # Root squash is a special mapping of the remote superuser (root) identity # when using identity authentication. # @!attribute [rw] allow_suid # @return [::Boolean] # Allow the setuid flag. # @!attribute [rw] allow_dev # @return [::Boolean] # Allow dev flag in NfsShare AllowedClientsRequest. class NfsExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Permissions that can granted for an export. module Permissions # Unspecified value. PERMISSIONS_UNSPECIFIED = 0 # Read-only permission. READ_ONLY = 1 # Read-write permission. READ_WRITE = 2 end end # The types of Volumes. module Type # The unspecified type. TYPE_UNSPECIFIED = 0 # This Volume is on flash. FLASH = 1 # This Volume is on disk. DISK = 2 end # The protocol used to access the volume. module Protocol # Unspecified value. PROTOCOL_UNSPECIFIED = 0 # Fibre channel. PROTOCOL_FC = 1 # Network file system. PROTOCOL_NFS = 2 end end |