Class: Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb

Overview

A NFS export entry.

Defined Under Namespace

Modules: Permissions

Instance Attribute Summary collapse

Instance Attribute Details

#allow_dev::Boolean

Returns Allow dev flag in NfsShare AllowedClientsRequest.

Returns:

  • (::Boolean)

    Allow dev flag in NfsShare AllowedClientsRequest.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end

#allow_suid::Boolean

Returns Allow the setuid flag.

Returns:

  • (::Boolean)

    Allow the setuid flag.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end

#cidr::String

Returns A CIDR range.

Note: The following fields are mutually exclusive: cidr, machine_id. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    A CIDR range.

    Note: The following fields are mutually exclusive: cidr, machine_id. If a field in that set is populated, all other fields in the set will automatically be cleared.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end

#machine_id::String

Returns Either a single machine, identified by an ID, or a comma-separated list of machine IDs.

Note: The following fields are mutually exclusive: machine_id, cidr. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Either a single machine, identified by an ID, or a comma-separated list of machine IDs.

    Note: The following fields are mutually exclusive: machine_id, cidr. If a field in that set is populated, all other fields in the set will automatically be cleared.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end

#network_id::String

Returns Network to use to publish the export.

Returns:

  • (::String)

    Network to use to publish the export.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end

#no_root_squash::Boolean

Returns Disable root squashing, which is a feature of NFS. Root squash is a special mapping of the remote superuser (root) identity when using identity authentication.

Returns:

  • (::Boolean)

    Disable root squashing, which is a feature of NFS. Root squash is a special mapping of the remote superuser (root) identity when using identity authentication.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end

#permissions::Google::Cloud::BareMetalSolution::V2::VolumeConfig::NfsExport::Permissions

Returns Export permissions.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 390

class NfsExport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Permissions that can granted for an export.
  module Permissions
    # Unspecified value.
    PERMISSIONS_UNSPECIFIED = 0

    # Read-only permission.
    READ_ONLY = 1

    # Read-write permission.
    READ_WRITE = 2
  end
end