Class: Google::Cloud::BareMetalSolution::V2::ProvisioningQuota
- Inherits:
-
Object
- Object
- Google::Cloud::BareMetalSolution::V2::ProvisioningQuota
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb
Overview
A provisioning quota for a given project.
Defined Under Namespace
Modules: AssetType
Instance Attribute Summary collapse
-
#asset_type ⇒ ::Google::Cloud::BareMetalSolution::V2::ProvisioningQuota::AssetType
The asset type of this provisioning quota.
-
#available_count ⇒ ::Integer
The available count of the provisioning quota.
-
#gcp_service ⇒ ::String
The gcp service of the provisioning quota.
-
#instance_quota ⇒ ::Google::Cloud::BareMetalSolution::V2::InstanceQuota
Instance quota.
-
#location ⇒ ::String
The specific location of the provisioining quota.
-
#name ⇒ ::String
readonly
Output only.
-
#network_bandwidth ⇒ ::Integer
Network bandwidth, Gbps.
-
#server_count ⇒ ::Integer
Server count.
-
#storage_gib ⇒ ::Integer
Storage size (GB).
Instance Attribute Details
#asset_type ⇒ ::Google::Cloud::BareMetalSolution::V2::ProvisioningQuota::AssetType
Returns The asset type of this provisioning quota.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#available_count ⇒ ::Integer
Returns The available count of the provisioning quota.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#gcp_service ⇒ ::String
Returns The gcp service of the provisioning quota.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#instance_quota ⇒ ::Google::Cloud::BareMetalSolution::V2::InstanceQuota
Returns Instance quota.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#location ⇒ ::String
Returns The specific location of the provisioining quota.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#name ⇒ ::String (readonly)
Returns Output only. The name of the provisioning quota.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#network_bandwidth ⇒ ::Integer
Returns Network bandwidth, Gbps
Note: The following fields are mutually exclusive: network_bandwidth, server_count, storage_gib. If a field in that set is populated, all other fields in the set will automatically be cleared.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#server_count ⇒ ::Integer
Returns Server count.
Note: The following fields are mutually exclusive: server_count, network_bandwidth, storage_gib. If a field in that set is populated, all other fields in the set will automatically be cleared.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |
#storage_gib ⇒ ::Integer
Returns Storage size (GB).
Note: The following fields are mutually exclusive: storage_gib, server_count, network_bandwidth. If a field in that set is populated, all other fields in the set will automatically be cleared.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'proto_docs/google/cloud/baremetalsolution/v2/provisioning.rb', line 167 class ProvisioningQuota include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The available asset types for intake. module AssetType # The unspecified type. ASSET_TYPE_UNSPECIFIED = 0 # The server asset type. ASSET_TYPE_SERVER = 1 # The storage asset type. ASSET_TYPE_STORAGE = 2 # The network asset type. ASSET_TYPE_NETWORK = 3 end end |